Exception: SmilyCli::ConfigurationError
- Defined in:
- lib/smily_cli/errors.rb,
sig/smily_cli.rbs
Overview
Raised when configuration/credentials are missing or malformed, e.g. no token could be resolved from flags, environment, or the config file.
Raised when configuration/credentials are missing or malformed, e.g. no token could be resolved from flags, environment, or the config file.