Module: SmilyCli::ResourceCommand::Bound

Defined in:
lib/smily_cli/resource_command.rb

Overview

Generated subclasses live here so they have real constant names (Thor derives a command namespace from the class name).